MulSeries
========================

.. toctree::
   :maxdepth: 1
   :caption: Constructor:

   mulseries

.. toctree::
   :maxdepth: 1
   :caption: Attributes:

   index
   name
   values
   ss
   ds
   shape
   primary_index
   primary_name
   mindex
   mname
   pindex
   pname

.. toctree::
   :maxdepth: 1
   :caption: indexing:

   iloc
   loc
   mloc
   nloc

.. toctree::
   :maxdepth: 1
   :caption: Methods:

   __iter__
   copy
   equals
   reset_index
   query
   sort_values
   drop_duplicates
   call
   groupby
   insert
   drop

